<?php

namespace Drupal\accessibility_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Accessibility Tools block' block.
 *
 * @Block(
 *  id = "accessibility_block",
 *  admin_label = @Translation("Accessibility Tools Block"),
 * )
 */
class AccessibilityTools extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {

    $config = $this->getConfiguration();

    $dark_mode = isset($config['dark_mode']) ? $config['dark_mode'] : FALSE;
    $font_resize = isset($config['font_resize']) ? $config['font_resize'] : FALSE;

    return [
      '#theme' => 'accessibility_block',
      '#attached' => [
        'library' => [
          'accessibility_block/accessibility',
        ],
      ],
      'class' => [
        'accessibility_tools_block',
      ],
      '#dark_mode' => $dark_mode,
      '#font_resize' => $font_resize,
    ];

    
  }


  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();


    $form['dark_mode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable Dark Mode'),
      '#default_value' => isset($config['dark_mode']) ? $config['dark_mode'] : FALSE,
    ];

    $form['font_resize'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable Font Resize'),
      '#default_value' => isset($config['font_resize']) ? $config['font_resize'] : FALSE,
    ];
    $form['#open'] = TRUE;
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);

    $values = $form_state->getValues();

    $this->configuration['dark_mode'] = $values['dark_mode'];
    $this->configuration['font_resize'] = $values['font_resize'];

  }


}
